EXPORTS
	??0CFlowContext@@IAE@PBXPAVMFlowManager@@@Z @ 1 NONAME ; protected: __thiscall CFlowContext::CFlowContext(void const *,class MFlowManager *)
	??0CFlowContext@@IAE@PBXPAVMFlowManager@@AAV0@@Z @ 2 NONAME ; protected: __thiscall CFlowContext::CFlowContext(void const *,class MFlowManager *,class CFlowContext &)
	??0TPacketPoker@@QAE@AAVRMBufChain@@@Z @ 3 NONAME ; public: __thiscall TPacketPoker::TPacketPoker(class RMBufChain &)
	??1CFlowContext@@MAE@XZ @ 4 NONAME ; protected: virtual __thiscall CFlowContext::~CFlowContext(void)
	??1CProtocolInet6Binder@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CProtocolInet6Binder::~CProtocolInet6Binder(void)
	?Access@RMBufPacketPeek@@QAE?AVTPtr8@@HI@Z @ 6 NONAME ; public: class TPtr8  __thiscall RMBufPacketPeek::Access(int,unsigned int)
	?Add@TChecksum@@QAEXAAVRMBufChain@@H@Z @ 7 NONAME ; public: void __thiscall TChecksum::Add(class RMBufChain &,int)
	?Add@TChecksum@@QAEXAAVRMBufChain@@PBVRMBufPktInfo@@H@Z @ 8 NONAME ; public: void __thiscall TChecksum::Add(class RMBufChain &,class RMBufPktInfo const *,int)
	?AddDestinationOptionL@TPacketHead@@QAEXABVTPtrC8@@EE@Z @ 9 NONAME ; public: void __thiscall TPacketHead::AddDestinationOptionL(class TPtrC8 const &,unsigned char,unsigned char)
	?AddDestinationOptionL@TPacketHead@@QAEXPBEEEE@Z @ 10 NONAME ; public: void __thiscall TPacketHead::AddDestinationOptionL(unsigned char const *,unsigned char,unsigned char,unsigned char)
	?AddOrdered@SequenceBlockQueue@@QAEPAVSequenceBlock@@VTTcpSeqNum@@0@Z @ 11 NONAME ; public: class SequenceBlock * __thiscall SequenceBlockQueue::AddOrdered(class TTcpSeqNum,class TTcpSeqNum)
	?AddUnordered@SequenceBlockQueue@@QAEPAVSequenceBlock@@VTTcpSeqNum@@0@Z @ 12 NONAME ; public: class SequenceBlock * __thiscall SequenceBlockQueue::AddUnordered(class TTcpSeqNum,class TTcpSeqNum)
	?AdjustL@TPacketPoker@@AAEPAEH@Z @ 13 NONAME ; private: unsigned char * __thiscall TPacketPoker::AdjustL(int)
	?BindToL@CProtocolInet6Binder@@UAEXPAVCProtocolBase@@@Z @ 14 NONAME ; public: virtual void __thiscall CProtocolInet6Binder::BindToL(class CProtocolBase *)
	?Calculate@TChecksum@@SAKPBGH@Z @ 15 NONAME ; public: static unsigned long __cdecl TChecksum::Calculate(unsigned short const *,int)
	?Cancel@TimeoutFactory@@CAXAAVRTimeout@@@Z @ 16 NONAME ; private: static void __cdecl TimeoutFactory::Cancel(class RTimeout &)
	?Clear@SequenceBlockQueue@@QAEXXZ @ 17 NONAME ; public: void __thiscall SequenceBlockQueue::Clear(void)
	?Clone@RFlowContext@@QAEHABV1@@Z @ 18 NONAME ; public: int __thiscall RFlowContext::Clone(class RFlowContext const &)
	?Close@CFlowContext@@QAEXXZ @ 19 NONAME ; public: void __thiscall CFlowContext::Close(void)
	?Close@RFlowContext@@QAEXXZ @ 20 NONAME ; public: void __thiscall RFlowContext::Close(void)
	?Connect@RFlowContext@@QAEHXZ @ 21 NONAME ; public: int __thiscall RFlowContext::Connect(void)
	?Copy@RFlowContext@@QAEXAAV1@@Z @ 22 NONAME ; public: void __thiscall RFlowContext::Copy(class RFlowContext &)
	?DoBindTo@CProtocolInet6Binder@@IAEHPAVCProtocolBase@@@Z @ 23 NONAME ; protected: int __thiscall CProtocolInet6Binder::DoBindTo(class CProtocolBase *)
	?ExtHdrGet@TPacketHead@@QAEHHAAH0@Z @ 24 NONAME ; public: int __thiscall TPacketHead::ExtHdrGet(int,int &,int &)
	?ExtHdrGetOrAppendL@TPacketHead@@QAEHHAAH0@Z @ 25 NONAME ; public: int __thiscall TPacketHead::ExtHdrGetOrAppendL(int,int &,int &)
	?ExtHdrGetOrPrependL@TPacketHead@@QAEHHAAH0@Z @ 26 NONAME ; public: int __thiscall TPacketHead::ExtHdrGetOrPrependL(int,int &,int &)
	?Find@SequenceBlockQueue@@QAEPAVSequenceBlock@@VTTcpSeqNum@@@Z @ 27 NONAME ; public: class SequenceBlock * __thiscall SequenceBlockQueue::Find(class TTcpSeqNum)
	?FindGap@SequenceBlockQueue@@QAEHAAVTTcpSeqNum@@0@Z @ 28 NONAME ; public: int __thiscall SequenceBlockQueue::FindGap(class TTcpSeqNum &,class TTcpSeqNum &)
	?GetIpHeader@RMBufPacketPeek@@QAEPAVTIpHeader@@XZ @ 29 NONAME ; public: class TIpHeader * __thiscall RMBufPacketPeek::GetIpHeader(void)
	?Grab@RFlowContext@@QAEXAAV1@@Z @ 30 NONAME ; public: void __thiscall RFlowContext::Grab(class RFlowContext &)
	?Init@TTcpOptions@@QAEXXZ @ 31 NONAME ; public: void __thiscall TTcpOptions::Init(void)
	?Interface@RFlowContext@@QBEPAVCNifIfBase@@XZ @ 32 NONAME ; public: class CNifIfBase * __thiscall RFlowContext::Interface(void)const 
	?IsActive@TimeoutFactory@@CAHABVRTimeout@@@Z @ 33 NONAME ; private: static int __cdecl TimeoutFactory::IsActive(class RTimeout const &)
	?IsExtensionHeader@TPacketPoker@@SAHH@Z @ 34 NONAME ; public: static int __cdecl TPacketPoker::IsExtensionHeader(int)
	?Length@TTcpOptions@@QBEHXZ @ 35 NONAME ; public: int __thiscall TTcpOptions::Length(void)const 
	?Limit@SequenceBlockQueue@@QAEXH@Z @ 36 NONAME ; public: void __thiscall SequenceBlockQueue::Limit(int)
	?NewHostResolverL@CProtocolInet6Binder@@UAEPAVCHostResolvProvdBase@@XZ @ 37 NONAME ; public: virtual class CHostResolvProvdBase * __thiscall CProtocolInet6Binder::NewHostResolverL(void)
	?NewL@TimeoutFactory@@SAPAVMTimeoutManager@@IPAXH@Z @ 38 NONAME ; public: static class MTimeoutManager * __cdecl TimeoutFactory::NewL(unsigned int,void *,int)
	?NewNetDatabaseL@CProtocolInet6Binder@@UAEPAVCNetDBProvdBase@@XZ @ 39 NONAME ; public: virtual class CNetDBProvdBase * __thiscall CProtocolInet6Binder::NewNetDatabaseL(void)
	?NewServiceResolverL@CProtocolInet6Binder@@UAEPAVCServiceResolvProvdBase@@XZ @ 40 NONAME ; public: virtual class CServiceResolvProvdBase * __thiscall CProtocolInet6Binder::NewServiceResolverL(void)
	?Open@RFlowContext@@QAEHAAV1@PAVRMBufPktInfo@@@Z @ 41 NONAME ; public: int __thiscall RFlowContext::Open(class RFlowContext &,class RMBufPktInfo *)
	?Open@RFlowContext@@QAEHPAVMFlowManager@@ABVTSockAddr@@1III@Z @ 42 NONAME ; public: int __thiscall RFlowContext::Open(class MFlowManager *,class TSockAddr const &,class TSockAddr const &,unsigned int,unsigned int,unsigned int)
	?Open@RFlowContext@@QAEHPAVMFlowManager@@I@Z @ 43 NONAME ; public: int __thiscall RFlowContext::Open(class MFlowManager *,unsigned int)
	?OutputOptions@TTcpOptions@@AAEIPAEI@Z @ 44 NONAME ; private: unsigned int __thiscall TTcpOptions::OutputOptions(unsigned char *,unsigned int)
	?OverL@TPacketPoker@@AAEXH@Z @ 45 NONAME ; private: void __thiscall TPacketPoker::OverL(int)
	?ProcessOptions@TTcpOptions@@AAEHPBEI@Z @ 46 NONAME ; private: int __thiscall TTcpOptions::ProcessOptions(unsigned char const *,unsigned int)
	?Prune@SequenceBlockQueue@@QAEXVTTcpSeqNum@@@Z @ 47 NONAME ; public: void __thiscall SequenceBlockQueue::Prune(class TTcpSeqNum)
	?ReOpen@RFlowContext@@QAEHXZ @ 48 NONAME ; public: int __thiscall RFlowContext::ReOpen(void)
	?RetrieveOption@CFlowContext@@QBEHIIAAVTDes8@@@Z @ 49 NONAME ; public: int __thiscall CFlowContext::RetrieveOption(unsigned int,unsigned int,class TDes8 &)const 
	?SetIcmpType@RFlowContext@@QAEXII@Z @ 50 NONAME ; public: void __thiscall RFlowContext::SetIcmpType(unsigned int,unsigned int)
	?SetLocalAddr@RFlowContext@@QAEXABVTSockAddr@@@Z @ 51 NONAME ; public: void __thiscall RFlowContext::SetLocalAddr(class TSockAddr const &)
	?SetNotify@RFlowContext@@QAEPAVMProviderNotify@@PAV2@@Z @ 52 NONAME ; public: class MProviderNotify * __thiscall RFlowContext::SetNotify(class MProviderNotify *)
	?SetProtocol@RFlowContext@@QAEXI@Z @ 53 NONAME ; public: void __thiscall RFlowContext::SetProtocol(unsigned int)
	?SetRemoteAddr@RFlowContext@@QAEXABVTSockAddr@@@Z @ 54 NONAME ; public: void __thiscall RFlowContext::SetRemoteAddr(class TSockAddr const &)
	?SetStatus@CFlowContext@@QAEXH@Z @ 55 NONAME ; public: void __thiscall CFlowContext::SetStatus(int)
	?Status@CFlowContext@@QAEHXZ @ 56 NONAME ; public: int __thiscall CFlowContext::Status(void)
	?Status@RFlowContext@@QAEHXZ @ 57 NONAME ; public: int __thiscall RFlowContext::Status(void)
	?StoreOption@CFlowContext@@QAEHIIABVTDesC8@@@Z @ 58 NONAME ; public: int __thiscall CFlowContext::StoreOption(unsigned int,unsigned int,class TDesC8 const &)
	??1CProtocolPosthook@@MAE@XZ @ 59 NONAME ; protected: virtual __thiscall CProtocolPosthook::~CProtocolPosthook(void)
	?BindL@CProtocolPosthook@@UAEXPAVCProtocolBase@@I@Z @ 60 NONAME ; public: virtual void __thiscall CProtocolPosthook::BindL(class CProtocolBase *,unsigned int)
	?BindToL@CProtocolPosthook@@UAEXPAVCProtocolBase@@@Z @ 61 NONAME ; public: virtual void __thiscall CProtocolPosthook::BindToL(class CProtocolBase *)
	?DoBindToL@CProtocolPosthook@@IAEHPAVCProtocolBase@@@Z @ 62 NONAME ; protected: int __thiscall CProtocolPosthook::DoBindToL(class CProtocolBase *)
	?Process@CProtocolPosthook@@UAEXAAVRMBufChain@@PAVCProtocolBase@@@Z @ 63 NONAME ; public: virtual void __thiscall CProtocolPosthook::Process(class RMBufChain &,class CProtocolBase *)
	?Send@CProtocolPosthook@@UAEHAAVRMBufChain@@PAVCProtocolBase@@@Z @ 64 NONAME ; public: virtual int __thiscall CProtocolPosthook::Send(class RMBufChain &,class CProtocolBase *)
	?Unbind@CProtocolPosthook@@UAEXPAVCProtocolBase@@I@Z @ 65 NONAME ; public: virtual void __thiscall CProtocolPosthook::Unbind(class CProtocolBase *,unsigned int)
	?CreateEventManager@MEventService@@SAPAV1@I@Z @ 66 NONAME ; public: static class MEventService * __cdecl MEventService::CreateEventManager(unsigned int)
	?CreateDstCache@MDestinationCache@@SAPAV1@H@Z @ 67 NONAME ; public: static class MDestinationCache * __cdecl MDestinationCache::CreateDstCache(int)
	?Access@TInet6PacketBase@@QAEPAEAAVRMBufChain@@HHH@Z @ 68 NONAME ; public: unsigned char * __thiscall TInet6PacketBase::Access(class RMBufChain &,int,int,int)
	?IsNdResolutionPending@RFlowContext@@QAEHXZ @ 69 NONAME ; int RFlowContext::IsNdResolutionPending(void)

